/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule deletion-dialog-controller
 */

(function() {
var DeletionDialogController;
var prototype;
var superConstructor;
var DeletionDialogView = dixim.autoDownload.DeletionDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientAutoDownload = dixim.common.ApiClientAutoDownload;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var Enum = dixim.ctt.util.Enum;

/**
 * @class DeletionDialogController
 * @constructor
 * @param {Object} configs
 */
DeletionDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(DeletionDialogController, EventTarget);
dixim.autoDownload.DeletionDialogController = DeletionDialogController;
prototype = DeletionDialogController.prototype;
superConstructor = DeletionDialogController.superConstructor;

var YES = 'yes';
var COMPLETE = 'complete';
var CLOSE = 'close';
var UPDATE = 'update';

var Mode = Enum.fetch('DELETION');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'deletion-dialog'].join('');

    this._mode = configs.mode;

    this._model = new ApiClientAutoDownload();
    switch(this._mode) {
        case Mode.TASK:
            this._model.addEventListener('removeTask', this._success, this);
            this._model.addEventListener('removeTaskError', this._error, this);
            break;
        case Mode.FILTER:
            this._model.addEventListener('removeFilter', this._success, this);
            this._model.addEventListener('removeFilterError', this._error, this);
            break;
    };

    this._view = new DeletionDialogView(configs);
    this._view.addEventListener(YES, this._clickYes, this);
    this._view.addEventListener(COMPLETE, this._complete, this);

    this._contents = configs.contents;
    this._isProcessError;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._success = function() {
    this._view.decrementDescription();
};

prototype._error = function() {
    this._isProcessError = true;
    this._view.decrementDescription();
};

prototype._deleteContents = function() {
    var contentsLen = this._contents.length;
    var query = {};

    this._isProcessError = false;
    for (var i = 0; i < contentsLen; i += 1) {
        switch(this._mode) {
            case Mode.TASK:
                query.taskId = this._contents[i].taskId;
                this._model.removeTask(query);
                break;
            case Mode.FILTER:
                query.filterId = this._contents[i].filterId;
                this._model.removeFilter(query);
                break;
        }
    }
};

prototype._complete = function() {
    this.stop();
    if (this._isProcessError) {
        this._errorDialog(_('auto_download_delete_error'));
        this.dispatchEvent(new Event(CLOSE));
    } else {
        this.dispatchEvent(new Event(UPDATE));
    }
};

prototype._clickYes = function() {
    this._deleteContents();
};

prototype._errorDialog = function(text) {
    var query = {};
    var dialog;

    switch(this._mode) {
        case Mode.TASK:
            query.title = _('auto_download_operation_delete_task');
            break;
        case Mode.FILTER:
            query.title = _('auto_download_filter_del_title');
            break;
    }
    query.id = this._id;
    query.doubleDialog = true;
    query.description = text;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

}());
