/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule aggregation-default-setting-controller
 */

(function() {
var AggregationDefaultSettingController;
var prototype;
var superConstructor;
var AggregationDefaultSettingView = dixim.vdms.AggregationDefaultSettingView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientVdms = dixim.common.ApiClientVdms;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var BlockUi = dixim.common.BlockUi;

/**
 * @class AggregationDefaultSettingController
 * @constructor
 * @param {Object} configs
 */
AggregationDefaultSettingController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AggregationDefaultSettingController, EventTarget);
dixim.vdms.AggregationDefaultSettingController = AggregationDefaultSettingController;
prototype = AggregationDefaultSettingController.prototype;
superConstructor = AggregationDefaultSettingController.superConstructor;

var PREV = 'prev';
var APPLY = 'apply';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'aggregation-default-setting'].join('');

    this._model = new ApiClientVdms();
    this._model.addEventListener('fetchDefaultAggregation', this._successFetchDefaultAggregation, this);
    this._model.addEventListener('fetchDefaultAggregationError', this._errorFetchDefaultAggregation, this);
    this._model.addEventListener('setDefaultAggregation', this._successSetDefaultAggregation, this);
    this._model.addEventListener('setDefaultAggregationError', this._errorSetDefaultAggregation, this);

    this._view = new AggregationDefaultSettingView(configs);
    this._view.addEventListener(PREV, this._clickPrev, this);
    this._view.addEventListener(APPLY, this._clickApply, this);

    this._blockUi = new BlockUi();
    this._parentContext = configs.parentContext;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
    this._fetchDefaultAggregation();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._fetchDefaultAggregation = function() {
    this._blockUi.block();
    this._model.fetchDefaultAggregation();
};

prototype._successFetchDefaultAggregation = function(e) {
    var defaultCrawl = e.args.defaultCrawl;

    if (defaultCrawl === 1) {
        this._view.setSetting(true);
    } else if (defaultCrawl === 0) {
        this._view.setSetting(false);
    } else {
        this._view.setSetting();
    }
    this._blockUi.unblock();
};

prototype._errorFetchDefaultAggregation = function() {
    this._errorDialog(_('vdms_aggregation_default_fetch_error'));
    this._view.setSetting();
};

prototype._successSetDefaultAggregation = function() {
    this._blockUi.unblock();
    this._fetchDefaultAggregation();
};

prototype._errorSetDefaultAggregation = function() {
    this._blockUi.unblock();
    this._errorDialog(_('vdms_aggregation_default_set_error'));
};

prototype._errorDialog = function(text) {
    var dialog = null;
    var query = {};

    query.id = this._id;
    query.title = _('vdms_aggregation_default_name');
    query.description = text;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

prototype._clickApply = function(e) {
    var isCrawl = e.args.isCrawl;
    var query = {};

    this._blockUi.block();

    query.defaultCrawl = (isCrawl) ? 1 : 0;
    this._model.setDefaultAggregation(query);
};

}());
