/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule aggregation-default-setting-view
 */

(function() {
var AggregationDefaultSettingView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class AggregationDefaultSettingView
 * @constructor
 * @param {Object} configs
 */
AggregationDefaultSettingView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AggregationDefaultSettingView, EventTarget);
dixim.vdms.AggregationDefaultSettingView = AggregationDefaultSettingView;
prototype = AggregationDefaultSettingView.prototype;
superConstructor = AggregationDefaultSettingView.superConstructor;

var PREV = 'prev';
var APPLY = 'apply';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._title = _('vdms_aggregation_menu_default');
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<div class="dl_tbl">',
        '<dl>',
        '<dt>', _('vdms_aggregation_default_name'), '</dt>',
        '<dd>',
        '<p>', _('vdms_aggregation_default_description'), '</p>',
        '<label id="default_aggregate" class="select-pointer">',
        '<input type="radio" name="aggregation_default" />',
        '<span>', _('vdms_aggregation_default_aggregate'), '</span>',
        '</label>',
        '<label id="default_non_aggregate" class="select-pointer">',
        '<input type="radio" name="aggregation_default" />',
        '<span>', _('vdms_aggregation_default_non_aggregate'), '</span>',
        '</label>',
        '</dd>',
        '</dl>',
        '</div>',
        '</div>',
        '</div>',
    ].join(''));

    UiUtils.cleanActionSettingBar();
    UiUtils.cleanActionBar();
    UiUtils.setActionBar('ab_apply', dixim.proxy(this._clickApply, this));

    $('.art_tit').text(this._title);
    $('.btn_prev').show().one('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
    $('.rootPage').empty();
};

prototype.setSetting = function(isAggregate) {
    if (typeof isAggregate === 'undefined') {
        $('#default_aggregate [type="radio"]').prop('checked', false);
        $('#default_non_aggregate [type="radio"]').prop('checked', false);
        return;
    }
    if (isAggregate) {
        $('#default_aggregate [type="radio"]').prop('checked', true);
    } else {
        $('#default_non_aggregate [type="radio"]').prop('checked', true);
    }
};

prototype._clickApply = function() {
    var checkedId = $('.contents_inner [type="radio"]:checked').closest('label').prop('id');

    this.dispatchEvent(new Event(APPLY, {isCrawl: (checkedId === 'default_aggregate')}));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

}());
