/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule permission-menu-controller
 */

(function() {
var AggregationMenuController;
var prototype;
var superConstructor;
var AggregationMenuView = dixim.vdms.AggregationMenuView;
var EventTarget = dixim.event.EventTarget;
var AggregationOperationController = dixim.vdms.AggregationOperationController;
var AggregationDefaultSettingController = dixim.vdms.AggregationDefaultSettingController;

/**
 * @class AggregationMenuController
 * @constructor
 * @param {Object} configs
 */
AggregationMenuController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AggregationMenuController, EventTarget);
dixim.vdms.AggregationMenuController = AggregationMenuController;
prototype = AggregationMenuController.prototype;
superConstructor = AggregationMenuController.superConstructor;

var AGGREGATE = 'aggregate';
var NON_AGGREGATE = 'nonAggregate';
var DEFAULT = 'default';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._view = new AggregationMenuView(configs);
    this._view.addEventListener(PREV, this._clickPrev, this);
    this._view.addEventListener(AGGREGATE, this._clickAggregate, this);
    this._view.addEventListener(NON_AGGREGATE, this._clickNonAggregate, this);
    this._view.addEventListener(DEFAULT, this._clickDefault, this);

    this._parentContext = configs.parentContext;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

prototype._clickAggregate = function() {
    var query = {};
    var controller;

    query.parentContext = this;
    query.isAggregatedDevice = true;
    controller = new AggregationOperationController(query);
    controller.start()
};

prototype._clickNonAggregate = function() {
    var query = {};
    var controller;

    query.parentContext = this;
    query.isAggregatedDevice = false;
    controller = new AggregationOperationController(query);
    controller.start()
};

prototype._clickDefault = function() {
    var query = {};
    var controller;

    query.parentContext = this;
    controller = new AggregationDefaultSettingController(query);
    controller.start()
};

}());
