/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule aggregation-operation-view
 */

(function() {
var AggregationOperationView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var Configs = dixim.ctt.Configs;
var UiUtils = dixim.common.UiUtils;
var $ = dixim.ctt.jQuery;

/**
 * @class AggregationOperationView
 * @constructor
 * @param {Object} configs
 */
AggregationOperationView = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AggregationOperationView, EventTarget);
dixim.vdms.AggregationOperationView = AggregationOperationView;
prototype = AggregationOperationView.prototype;
superConstructor = AggregationOperationView.superConstructor;

var PREV = 'prev';
var SELECT = 'select';
var OPERATE = 'operate';
var REFRESH = 'refresh';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    this._selectedInfo = {};
    this._isAggregatedDevice = configs.isAggregatedDevice;

    if (this._isAggregatedDevice) {
        this._title = _('vdms_aggregation_menu_aggregation');
    } else {
        this._title = _('vdms_aggregation_menu_non_aggregation');
    }
};

/**
 * @method show
 */
prototype.show = function() {
    $('.rootPage').html([
        '<div class="contents" data-enhance="false">',
        '<h2 id="tit_page">', this._title, '</h2>',
        '<div class="contents_inner">',
        '<table class="tbl_list">',
        '<colgroup>',
        '<col span="1" class="checkbox">',
        '<col span="1" class="list_img">',
        '<col span="1" class="list_info">',
        '</colgroup>',
        '<tbody>',
        '</tbody>',
        '</table>',
        '</div>',
        '</div>',
    ].join(''));

    UiUtils.cleanActionSettingBar();
    UiUtils.cleanActionBar();
    UiUtils.setActionBar('ab_select', dixim.proxy(this._clickSelect, this));
    UiUtils.setActionBar('ab_operate', dixim.proxy(this._clickOperate, this));
    UiUtils.disableActionBar('ab_select');
    UiUtils.disableActionBar('ab_operate');
    UiUtils.showActionSettingBar('ac_refresh', dixim.proxy(this._clickRefresh, this));

    $('.art_tit').text(this._title);
    $('.btn_prev').show().one('click', dixim.proxy(this._clickPrev, this));
};

/**
 * @method hide
 */
prototype.hide = function() {
    this._selectedInfo = {};
    $('.rootPage').empty();
};

prototype.noDevice = function() {
    var text = '';

    UiUtils.disableActionBar('ab_select');
    UiUtils.disableActionBar('ab_operate');
    if (this._isAggregatedDevice) {
        text = _('vdms_aggregation_no_device_aggregation');
    } else {
        text = _('vdms_aggregation_no_device_non_aggregation');
    }
    $('.contents_inner').html([
        '<div class="error-text-field txt_none">',
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.addDevice = function(data) {
    var rowSelector;
    var icon = [Configs.get('imagePath'), '/ico_list_server.png'].join('');

    UiUtils.enableActionBar('ab_select');
    UiUtils.enableActionBar('ab_operate');
    $('.contents_inner table tbody').append([
        '<tr>',
        '<td>',
        '<label class="select-pointer">', '<input type="checkbox" />',
        '<span>', '</span>',
        '</label>',
        '</td>',
        '<td class="img_box">',
        '<img src="', icon, '" class="rspd" width="120" height="120" alt />',
        '</td>',
        '<td>',
        '<h4 class="txt_m">', data.friendlyName, '</h4>',
        '<div class="list_detail txt_s">', '</div>',
        '</td>',
        '</tr>',
    ].join(''));
    rowSelector = $('.contents_inner table tbody tr:last-child');

    if (data.deviceIcon !== '') {
        rowSelector.find('img').prop('src', data.deviceIcon)
            .error(function() {
                $(this).prop('src', icon);
            });
    }
    rowSelector.find('.list_detail').html(this.checkServerStatus(data));
    rowSelector.find('[type="checkbox"]').on('change', data, dixim.proxy(this._changeCheckbox, this));
};

prototype.checkServerStatus = function(data) {
    var description = _('vdms_aggregation_status_unknown');
    var deviceStatusArray;
    var deviceStatus;

    if (typeof data.isRunning !== 'undefined' && ! data.isRunning) {
        description = _('vdms_aggregation_status_server_stop');
    } else if (typeof data.isRemoving !== 'undefined' && data.isRemoving) {
        description = _('vdms_aggregation_status_delete_in_progress');
    } else {
        if (this._isAggregatedDevice) {
            if (data.deviceStatus === 3) {
                description = _('vdms_aggregation_status_target_in_progress');
            } else if (data.deviceStatus === 4) {
                description = _('vdms_aggregation_status_not_target_in_progress');
            } else if (data.deviceStatus === 1) {
                if (data.syncStatus === 1) {
                    description = _('vdms_aggregation_status_wait');
                } else if (data.syncStatus === 2) {
                    description = _('vdms_aggregation_status_info_in_progress');
                } else if (data.syncStatus === 3) {
                    description = _('vdms_aggregation_status_info_complete');
                } else if (data.syncStatus === 4) {
                    description = _('vdms_aggregation_status_error_occurred');
                } else if (data.syncStatus === 5) {
                    description = _('vdms_aggregation_status_canceled');
                }
            }
        } else {
            deviceStatusArray = ('0000' + data.deviceStatus.toString(2)).slice(-4).split('');
            deviceStatus = deviceStatusArray.reverse();
            if (data.deviceStatus === 1) {
                description = _('vdms_aggregation_status_info_not_target');
                $('.contents_inner table tbody tr:last-child img').addClass('nocollect');
            }
        }
    }

    return description;
};

prototype.switchSelect = function() {
    var numberOfNotChecked = $('.tbl_list [type="checkbox"]').not(':checked').length;

    if (numberOfNotChecked > 0) {
        $('.tbl_list [type="checkbox"]').not(':checked').trigger('click');
    } else {
        $('.tbl_list [type="checkbox"]:checked').trigger('click');
    }
};

prototype._changeCheckbox = function(e) {
    if (e.currentTarget.checked) {
        this._selectedInfo[e.data.udn] = e.data;
    } else {
        delete this._selectedInfo[e.data.udn];
    }
};

prototype._clickSelect = function() {
    this.dispatchEvent(new Event(SELECT));
};

prototype._clickOperate = function() {
    this.dispatchEvent(new Event(OPERATE, this._selectedInfo));
};

prototype._clickRefresh = function() {
    this.dispatchEvent(new Event(REFRESH));
};

prototype._clickPrev = function() {
    this.dispatchEvent(new Event(PREV));
};

prototype.error = function(text) {
    $('#aggregation_error').remove();
    $('.contents_inner').append([
        '<div id="aggregation_error" class="error-text-field txt_none">',
        '<span>', text, '</span>',
        '</div>',
    ].join(''));
};

prototype.cleanList = function() {
    this._selectedInfo = {};
    $('.contents_inner table tbody').empty();
};

}());
