/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule contents-distribution-setting-controller
 */

(function() {
var ContentsDistributionSettingController;
var prototype;
var superConstructor;
var ContentsDistributionSettingView = dixim.vdms.ContentsDistributionSettingView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientVdms = dixim.common.ApiClientVdms;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var BlockUi = dixim.common.BlockUi;

/**
 * @class ContentsDistributionSettingController
 * @constructor
 * @param {Object} configs
 */
ContentsDistributionSettingController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(ContentsDistributionSettingController, EventTarget);
dixim.vdms.ContentsDistributionSettingController = ContentsDistributionSettingController;
prototype = ContentsDistributionSettingController.prototype;
superConstructor = ContentsDistributionSettingController.superConstructor;

var PREV = 'prev';
var APPLY = 'apply';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'contents-distribution-setting'].join('');

    this._model = new ApiClientVdms();
    this._model.addEventListener('fetchProxyMode', this._successFetchProxyMode, this);
    this._model.addEventListener('fetchProxyModeError', this._errorFetchProxyMode, this);
    this._model.addEventListener('setProxyMode', this._successSetProxyMode, this);
    this._model.addEventListener('setProxyModeError', this._errorSetProxyMode, this);

    this._view = new ContentsDistributionSettingView(configs);
    this._view.addEventListener(PREV, this._clickPrev, this);
    this._view.addEventListener(APPLY, this._clickApply, this);

    this._blockUi = new BlockUi();
    this._parentContext = configs.parentContext;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
    this._fetchProxyMode();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._fetchProxyMode = function() {
    this._blockUi.block();
    this._model.fetchProxyMode();
};

prototype._successFetchProxyMode = function(e) {
    var proxyMode = e.args.proxyMode;

    if (proxyMode === 1) {
        this._view.setSetting(true);
    } else if (proxyMode === 0) {
        this._view.setSetting(false);
    } else {
        this._view.setSetting();
    }
    this._blockUi.unblock();
};

prototype._errorFetchProxyMode = function() {
    this._errorDialog(_('vdms_distribution_fetch_error'));
    this._view.setSetting();
};

prototype._successSetProxyMode = function() {
    this._blockUi.unblock();
    this._fetchProxyMode();
};

prototype._errorSetProxyMode = function() {
    this._blockUi.unblock();
    this._errorDialog(_('vdms_distribution_set_error'));
};

prototype._errorDialog = function(text) {
    var dialog = null;
    var query = {};

    query.id = this._id;
    query.title = _('vdms_menu_distribution');
    query.description = text;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

prototype._clickApply = function(e) {
    var enableDistribution = e.args.enableDistribution;
    var query = {};

    this._blockUi.block();

    query.proxyMode = (enableDistribution) ? 1 : 0;
    this._model.setProxyMode(query);
};

}());
