/**
 * @module ctt
 * @submodule application-toolbar-view
 */
(function() {
var Event = dixim.event.Event;
var ToolbarView = dixim.ctt.ToolbarView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var ApplicationToolbarView;

/**
 * @class ApplicationToolbarView
 * @extends ToolbarView
 * @constructor
 * @param {Object} configs
 */
ApplicationToolbarView = function(configs) {
  ToolbarView.call(this, configs);
};
dixim.inherit(ApplicationToolbarView, ToolbarView);
dixim.ctt.ApplicationToolbarView = ApplicationToolbarView;
prototype = ApplicationToolbarView.prototype;
superConstructor = ApplicationToolbarView.superConstructor;

/**
 * Auto delete button ID.
 *
 * @property BUTTON_ID_AUTODELETE
 * @type {String}
 * @private
 * @static
 */
var BUTTON_ID_AUTODELETE = 'autodelete';

/**
 * Auto compression button ID.
 *
 * @property BUTTON_ID_AUTOCOMPRESSION
 * @type {String}
 * @private
 * @static
 */
var BUTTON_ID_COMPRESSION_SETTING = 'compression_setting';

/**
 * Unlock button ID.
 *
 * @property BUTTON_ID_UNLOCK
 * @type {String}
 * @private
 * @static
 */
var BUTTON_ID_UNLOCK = 'unlock';

/**
 * History button ID.
 *
 * @property BUTTON_ID_HISTORY
 * @type {String}
 * @private
 * @static
 */
var BUTTON_ID_HISTORY = 'history';

/**
 * Schedule button ID.
 *
 * @property BUTTON_ID_SCHEDULE
 * @type {String}
 * @private
 * @static
 */
var BUTTON_ID_SCHEDULE = 'schedule';

var BUTTONS = [
  {
    /**
     * Triggered when the Auto delete button is clicked.
     *
     * @event autodelete
     */
    id: BUTTON_ID_AUTODELETE,
    label: _('ctt_application_toolbar_button_autodelete'),
    icon: 'ico_setting.png'
  },
  {
    /**
     * Triggered when the AutoCompression button is clicked.
     *
     * @event autocompression
     */
    id: BUTTON_ID_COMPRESSION_SETTING,
    label: _('ctt_application_toolbar_button_compression_setting'),
    icon: 'ico_tc_setting.png'
  },
  {
    /**
     * Triggered when the Unlock button is clicked.
     *
     * @event unlock
     */
    id: BUTTON_ID_UNLOCK,
    label: _('ctt_application_toolbar_button_unlock'),
    icon: 'ico_Key.png'
  },
  {
    /**
     * Triggered when the History button is clicked.
     *
     * @event hitroy
     */
    id: BUTTON_ID_HISTORY,
    label: _('ctt_application_toolbar_button_history'),
    icon: 'ico_History.png'
  },
  {
    /**
     * Triggered when the Schedule button is clicked.
     *
     * @event schedule
     */
    id: BUTTON_ID_SCHEDULE,
    label: _('ctt_application_toolbar_button_schedule'),
    icon: 'ico_Rsv.png'
  }
];

/**
 * @property BUTTON_ID_AUTODELETE
 * @type {String}
 */
ApplicationToolbarView.BUTTON_ID_AUTODELETE = BUTTON_ID_AUTODELETE;

/**
 * @property BUTTON_ID_COMPRESSION_SETTING
 * @type {String}
 */
ApplicationToolbarView.BUTTON_ID_COMPRESSION_SETTING = BUTTON_ID_COMPRESSION_SETTING;

/**
 * @property BUTTON_ID_UNLOCK
 * @type {String}
 */
ApplicationToolbarView.BUTTON_ID_UNLOCK = BUTTON_ID_UNLOCK;

/**
 * @property BUTTON_ID_HISTORY
 * @type {String}
 */
ApplicationToolbarView.BUTTON_ID_HISTORY = BUTTON_ID_HISTORY;

/**
 * @property BUTTON_ID_SCHEDULE
 * @type {String}
 */
ApplicationToolbarView.BUTTON_ID_SCHEDULE = BUTTON_ID_SCHEDULE;

function getShownButtons(shownButtonIds) {
  var shownButtons = [];
  var lenButtons;
  var lenShownButtonIds;
  var button;
  var i;
  var j;

  lenButtons = BUTTONS.length;
  lenShownButtonIds = shownButtonIds.length;
  for (i = 0; i < lenButtons; ++i) {
    button = BUTTONS[i];
    for (j = 0; j < lenShownButtonIds; ++j) {
      if (button.id === shownButtonIds[j]) {
        shownButtons.push(button);
        break;
      }
    }
  }

  return shownButtons;
}

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {String} configs.containerNode
 * @param {Button[]} [configs.buttons]
 * @param {String[]} [configs.shownButtons]
 */
prototype._initialize = function(configs) {
  var buttons_id = [];

  this._isRemote = !!configs.isRemote;
  this._isAutoDelete = !!configs.isAutoDelete;
  this._isCompression = !!configs.isCompression;
  if (this._isRemote) {
    configs.buttons = getShownButtons([
      ApplicationToolbarView.BUTTON_ID_UNLOCK,
      ApplicationToolbarView.BUTTON_ID_HISTORY,
      ApplicationToolbarView.BUTTON_ID_SCHEDULE
    ]);
  } else {
    buttons_id.push(ApplicationToolbarView.BUTTON_ID_UNLOCK);
    buttons_id.push(ApplicationToolbarView.BUTTON_ID_HISTORY);
    buttons_id.push(ApplicationToolbarView.BUTTON_ID_SCHEDULE);
    if (!!this._isAutoDelete) {
      buttons_id.push(ApplicationToolbarView.BUTTON_ID_AUTODELETE);
    }
    if (!!this._isCompression) {
      buttons_id.push(ApplicationToolbarView.BUTTON_ID_COMPRESSION_SETTING);
    }
    configs.buttons = getShownButtons(buttons_id);
  }
  configs.className = 'ctt-application-toolbar-view';
  superConstructor.prototype._initialize.call(this, configs);
};

prototype.disableUnlockButton = function() {
  var id = BUTTON_ID_UNLOCK;
  var node;

  node = this._getButtonNode(id);
  node.addClass('ctt-application-toolbar-view-button-disabled');
  this._disableButton(id);
};

prototype.enableUnlockButton = function() {
  var id = BUTTON_ID_UNLOCK;
  var node;

  node = this._getButtonNode(id);
  node.removeClass('ctt-application-toolbar-view-button-disabled');
  this._enableButton(id);
};

}());
