/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule select-howto-download-dialog-view
 */

(function() {
var Event = dixim.event.Event;
var ModalDialogView = dixim.ctt.ModalDialogView;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var FilterSettingDialogController = dixim.ctt.ad.FilterSettingDialogController;
var ToolbarView = dixim.ctt.ToolbarView;
var ErrorDialog = dixim.ctt.ErrorDialog;
var Template = dixim.ctt.util.Template;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var SelectHowtoDownloadDialogView;
var prototype;
var superConstructor;

/**
 * @class SelectHowtoDownloadDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
SelectHowtoDownloadDialogView = function(configs) {
  ModalDialogView.call(this, configs);
};
dixim.inherit(SelectHowtoDownloadDialogView, ModalDialogView);
dixim.ctt.ad.SelectHowtoDownloadDialogView = SelectHowtoDownloadDialogView;
prototype = SelectHowtoDownloadDialogView.prototype;
superConstructor = SelectHowtoDownloadDialogView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div id="select-howto-download"/>';
var TEMPLATE_LOADING = Template.LOADING_ICON_SMALL;

var TEMPLATE_BODY_CONTENT = ['<h1 id="task-add-h1">',
                             '</h1>',
                             '<div id="howto-download-setting">',
                             '<table id="howto-download-setting-table">',
                             '</table>',
                             '<div id="select-filter-list-toolbar"></div>',
                             '<div id="select-filter-list-header" class="table_header"></div>',
                             '<div id="select-filter-list"></div>',
                             '</div>'
                             ].join('');

/**
 * Triggered when the cancel button was clicked.
 *
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * Triggered when the submit button was clicked.
 *
 * @event submit
 */
var SUBMIT = 'submit';

/**
 * Triggered when the back button was clicked.
 *
 * @event back
 */
var BACK = 'back';

/**
 * Triggered when the edit button was clicked.
 *
 * @event edit
 */
var EDIT = 'edit';

/**
 * Triggered when the delete button was clicked.
 *
 * @event delete
 */
var DELETE = 'delete';

/**
 * Triggered when the allselect button was clicked.
 *
 * @event allselect
 */
var ALLSELECT = 'allselect';

/**
 * Triggered when the allunselect button was clicked.
 *
 * @event allunselect
 */
var ALLUNSELECT = 'allunselect';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var buttonsError;

  configs  = configs || {};

  buttons = [
    {
      'text': _("ctt_ad_wizard_register_str"),
      class: 'ctt-how-to-submit',
      click: $.proxy(this._didClickSubmit, this),
      align: 'right'
    },
    {
      'text': _('ctt_transfer_wizard_button_label_back'),
      class: 'ctt-how-to-back',
      click: $.proxy(this._didClickBack, this),
      align: 'right'
    },
    {
      'text': _('ctt_dialog_button_label_cancel'),
      class: 'ctt-how-to-cancel',
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  buttonsError = [
    {
      'text': _('ctt_dialog_button_label_close'),
      click: $.proxy(this._didClickClose, this)
    }
  ];

  configs.title = configs.title || _("ctt_ad_wizard_how_to_download_setting");
  configs.contentBox = TEMPLATE_CONTENT_BOX;
  configs.bodyContent = TEMPLATE_BODY_CONTENT;
  configs.buttons = buttons;
  configs.width = 600;
  configs.height = 580;

  this._model = new AutoDownloadApiClient();
  this._loadingIcon = $(TEMPLATE_LOADING);
  this.result = {};

  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didCreateHowtoDownloadTable = function() {
  var hour_option = "";
  var minute_option = "";

  $('#task-add-h1').html(
     [
      '<span class="history_header">',
      _("ctt_ad_wizard_how_to_download_setting_list_str"),
      '</span>'
    ].join('')
  );
  $('#howto-download-setting-table').html(
     [
      '<tr><td colspan="3">',
      '<span id="priority_download_resource">',_("ctt_ad_wizard_priority_download_resource"),':','</span>',
      '</td></tr>',
      '<tr><td>',
      '<input type="checkbox" id="sd_resolution_checkbox">',
      '</td><td colspan="2">',
      '<span id="is_sd_resolution_priority_download">',_("ctt_ad_wizard_is_sd_resolution_priority_download"),'</span>',
      '</td></tr>',
      '<tr><td colspan="3">',
      '<span id="download_timing">',_("ctt_ad_wizard_download_timing"),':','<span>',
      '</td></tr>',
      '<tr><td>',
      '<input type="radio" id="asap_download_radio" name="download_timing" value="ASAP" checked>',
      '</td><td colspan="2">',
      '<span id="asap_download">',_("ctt_ad_wizard_asap_download"),'</span>',
      '</td></tr>',
      '<tr><td>',
      '<input type="radio" id="timed_download_radio" name="download_timing" value="TIMED">',
      '</td><td>',
      '<span id="timed_download">',_("ctt_ad_wizard_timed_download"),'</span>',
      '</td><td id="timed_selected">',
      '</td></tr>'
    ].join('')
  );

  for (var i = 0; i < 24; i += 1) {
    hour_option += ['<option value=',(("00"+i).slice(-2)),'>',i,'</option>'].join('');
  }
  for (var j = 0; j < 60; j += 10) {
    minute_option += ['<option value=',(("00"+j).slice(-2)),'>',(("00"+j).slice(-2)),'</option>'].join('');
  }

  $('#timed_selected').html(
      [
       '<select name="select_hour">',
       hour_option,
       '</select>',
       '<span id="hour_str">',_("ctt_ad_wizard_hour_str"),'</span>',
       '<select name="select_minute">',
       minute_option,
       '</select>',
       '<span id="minute_str">',_("ctt_ad_wizard_minute_str"),'</span>'
       ].join('')
  ).hide();

  $('#timed_download_radio').on('change', function() {
    $('#timed_selected').show();
  });
  $('#asap_download_radio').on('change', function() {
    $('#timed_selected').hide();
  });
};

prototype._didCreateToolbar = function() {
  this.toolbarView = new ToolbarView({
    containerNode: '#select-filter-list-toolbar',
    buttons: [
      {
        id: 'delete_all',
        label: _("ad_dialog_filter_list_toolbar_delete")
      },
      {
        id: 'select_all',
        label: _("ad_dialog_filter_list_toolbar_all_select")
      },
      {
        id: 'unselect_all',
        label: _("ad_dialog_filter_list_toolbar_all_unselect")
      },
      {
        id: 'filter_edit',
        label: _("ctt_ad_wizard_select_filter_list_change_filter"),
        align: 'right'
      }
    ]
  });

  var _howToDownloadDidClickFilterEdit = function() {
    this.dispatchEvent(new Event(EDIT));
  };

  var _howToDownloadDidClickDelete = function() {
    this.dispatchEvent(new Event(DELETE));
  };
  var _howToDownloadDidClickSelectAll = function() {
    this.dispatchEvent(new Event(ALLSELECT));
  };
  var _howToDownloadDidClickUnselectAll = function() {
    this.dispatchEvent(new Event(ALLUNSELECT));
  };

  var _setEventListeners = dixim.proxy(function() {
    this.toolbarView.addEventListener('filter_edit', _howToDownloadDidClickFilterEdit, this);
    this.toolbarView.addEventListener('delete_all', _howToDownloadDidClickDelete, this);
    this.toolbarView.addEventListener('select_all', _howToDownloadDidClickSelectAll, this);
    this.toolbarView.addEventListener('unselect_all', _howToDownloadDidClickUnselectAll, this);
  }, this);
  this.toolbarView.show();
  _setEventListeners();
};

prototype._didSelectAddOptionRow = function(option) {
  var value = option.value;
  var checkAndChangeName = function(name) {
    var new_name = '';
    var name_length = 0;
    var name_array = name.split('');
    var check_length = function(c) {
      if (c.match(/[a-z0-9]/)) {
        return 1;
      } else {
        return 1.8;
      }
    };

    for (var i = 0; i < name_array.length; i += 1) {
      name_length += check_length(name_array[i]);
      if (name_length < 45) {
        new_name += name_array[i];
      } else {
        new_name += "...";
        break;
      }
    }
    return new_name;
  };

  $('#select_filter_list_table select:last').append(
    [
      '<option value=',value,'>',
      '<span class="filter_name_option">',checkAndChangeName(option.name),'</span>',
      '</option>'
    ].join('')
  );
};

prototype._didAddFilterListRow = function() {
  var query = {};
  var addFilterListRow = dixim.proxy(this._didAddFilterListRow, this);

  $('#select_filter_list_table').append(
      [
       '<tr><td>',
       '<input type="checkbox" id="filter_list_checkbox','" class="filter_list_checkbox_class">',
       '<select id="filter_list_select" class="filter_select" disabled=true></select>',
       '</td></tr>',
    ].join('')
  );

  query.success = dixim.proxy(function(e) {
    var filters = e.args.filters;
    var filters_length = filters.length;
    var option;

    for (var i = 0; i < filters_length; i += 1) {
      option = {
          name: filters[i].filterName,
          value: filters[i].filterId
      };
      this._didSelectAddOptionRow(option);
    }
    option = {
        name: _('ctt_ad_wizard_create_new_filter'),
        value: "new"
    };
    this._didSelectAddOptionRow(option);
  }, this);
  query.error = dixim.proxy(function() {
    this._showErrorDialog("ctt_error_dialog_default");
  }, this);

  query.async = false;
  this._model.fetchDownloadFilterList(query);

  $('#select_filter_list_table input[type="checkbox"]').on('change', function() {
    if ($(this).is(":checked")) {
      $('.filter_select').triggerHandler("change");
      $(this).next().prop("disabled",false);
      if ($(this).parent("td").parent("tr").next().length === 0) {
        addFilterListRow($('#select_filter_list_table [type="checkbox"]').length);
      }
    } else {
      $(this).next().prop("disabled",true);
    }
  });
  $('.filter_select:last').on('change', function() {
    var query = {};
    var _setting;

    if ($(this).val() === "new") {

      query.finish = function(e) {
        var filter_data = e.args;
        var checkAndChangeName = function(name) {
          var new_name = '';
          var name_length = 0;
          var name_array = name.split('');
          var check_length = function(c) {
            if (c.match(/[a-z0-9]/)) {
              return 1;
            } else {
              return 1.8;
            }
          };

          for (var i = 0; i < name_array.length; i += 1) {
            name_length += check_length(name_array[i]);
            if (name_length < 55) {
              new_name += name_array[i];
            } else {
              new_name += "...";
              break;
            }
          }
          return new_name;
        };

        $('option[value="new"]').before(['<option value="',filter_data.filterId,'">',checkAndChangeName(filter_data.filterName),'</option>'].join(''));
        $('#select_filter_list_table [type="checkbox"]').each(function() {
          if ($(this).next().val() === "new") {
            $(this).next().val(filter_data.filterId);
           }
         });
       };
       query.afterClose = function() {
         $('#select_filter_list_table select').each(function() {
           if($(this).val() === "new") {
             if ($(this).find('option').length === 1) {
               $('#select_filter_list_table [type="checkbox"]:checked').parent('td').parent('tr').remove();
               }
             $(this).prev().prop('checked', false);
             $(this).prop('disabled', true);
             $(this).val($(this.firstChild).val());
            }
         });
       };
      _setting = new FilterSettingDialogController(query);
      _setting.start();
    }
  });
};

prototype._didCreateFilterList = function() {
  $('#select-filter-list-header').html(_("ctt_ad_wizard_select_filter_list_filter_name"));
  $('#select-filter-list').html('<table id="select_filter_list_table"></table>');
  this._didAddFilterListRow("0");
};

prototype._didRenderDialog = function(e) {
  this._didCreateHowtoDownloadTable();
  this._didCreateToolbar();
  this._didCreateFilterList();
  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._didCancel();
};

prototype._didClickCancel = function() {
  this._didCancel();
};

prototype._didCancel = function() {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._didClickSubmit = function() {
  var filter_list = [];

  this.result.sdFirst = $('#sd_resolution_checkbox').is(":checked");
  this.result.reservationType = $('[name="download_timing"]:checked').val();
  if (this.result.reservationType === "TIMED") {
    var hour = parseInt($('[name="select_hour"]').val(), 10);
    var minute = parseInt($('[name="select_minute"]').val(), 10);
    var time = hour * 60 + minute;
    this.result.timedReservationStartTime = time;
  }
  $('#select_filter_list_table [type="checkbox"]:checked').each(function() {
    filter_list.push(parseInt($(this).next().val(), 10));
  });
  this.result.filterList = filter_list;
  this.dispatchEvent(new Event(SUBMIT));
};

prototype._didClickBack = function() {
  this.dispatchEvent(new Event(BACK));
};

prototype.getSelectInfo = function() {
  return this.result;
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.show();
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

}());
