/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule setting-dialog-view
 */

(function() {
var Event = dixim.event.Event;
var ModalDialogView = dixim.ctt.ModalDialogView;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var Template = dixim.ctt.util.Template;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;
var ErrorDialog = dixim.ctt.ErrorDialog;

var SettingDialogView;
var prototype;
var superConstructor;

/**
 * @class SettingDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
SettingDialogView = function(configs) {
  ModalDialogView.call(this, configs);
};
dixim.inherit(SettingDialogView, ModalDialogView);
dixim.ctt.ad.SettingDialogView = SettingDialogView;
prototype = SettingDialogView.prototype;
superConstructor = SettingDialogView.superConstructor;

var TEMPLATE_CONTENT_BOX = '<div class="ctt-setting-view-wrapper" />';
var TEMPLATE_LOADING = Template.LOADING_ICON_SMALL;

var TEMPLATE_BODY_CONTENT = ['<table id="auto-download-setting-table">',
                               '<tbody>',
                                 '<tr class="auto-download-setting-threshold"></tr>',
                                 '<tr class="auto-download-setting-value-str"></tr>',
                                 '<tr class="auto-download-setting-move"></tr>',
                               '</tbody>',
                             '</table>'].join('');

/**
 * Triggered when the cancel button was clicked.
 *
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * Triggered when the save button was clicked.
 *
 * @event save
 */
var SAVE = 'save';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var buttonsError;

  configs  = configs || {};

  buttons = [
    {
      'text': _('ad_dialog_setting_save'),
      id: 'save',
      click: $.proxy(this._didClickSave, this),
      align: 'right'
    },
    {
      'text': _('ctt_dialog_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  buttonsError = [
    {
      'text': _('ctt_dialog_button_label_close'),
      click: $.proxy(this._didClickClose, this)
    }
  ];

  configs.title = configs.title || _('ad_dialog_setting_title');
  configs.contentBox = TEMPLATE_CONTENT_BOX;
  configs.bodyContent = TEMPLATE_BODY_CONTENT;
  configs.buttons = buttons;
  configs.width = 470;
  configs.height = 'auto';
  configs.maxHeight = 340;

  this._model = new AutoDownloadApiClient();
  this._loadingIcon = $(TEMPLATE_LOADING);
  this._errorNode = null;
  this._errorButtons = buttonsError;

  superConstructor.prototype._initialize.call(this, configs);
};

prototype._didCreateDialog = function() {
  $('.auto-download-setting-threshold').html(
      [
      '<td><span>',
      _("ad_dialog_setting_space_str"),
      '</span></td>',
      '<td><input type="text" id="empty_capacity"></td>',
      '<td><span>',
      _("ad_dialog_setting_space_unit"),
      '</span></td>'
      ].join('')
      );

    $('.auto-download-setting-value-str').html(
      [
       '<td></td>',
       '<td colspan="2"><span>',
       _("ad_dialog_setting_space_option"),
       '</span></td>'
      ].join('')
      );

    $('.auto-download-setting-move').html(
       [
        '<td><span>',
        _("ad_dialog_setting_move_str"),
        '</span></td>',
        '<td class="yes_td"><input type="radio" id="yes_radio" name="move_item_button"><span>',
        _("ad_dialog_setting_move_yes"),
        '</span></td>',
        '<td class="no_td"><input type="radio" id="no_radio" name="move_item_button"><span>',
        _("ad_dialog_setting_move_no"),
        '</span></td>'
      ].join('')
     );
    $('#save').after('<span id="check_threshold"></span>');
};

prototype._didEventForCheckThreshold = function() {
  $('#empty_capacity').on('keyup change', function() {
    var this_val = $(this).val();

    if (this_val.match(/^\d{1,3}$/) && this_val <= 100 && this_val > 0 && this_val !== '') {
      $('#save').prop('disabled', false);
      $('.ui-dialog-buttonset span').empty();
    } else {
      $('#save').prop('disabled', true);
      $('#check_threshold').html(_("ad_dialog_setting_check_threshold"));
    }
  });
};

prototype._didSetValueDialog = function() {
  this._model.fetchMoveSetting({
    success: dixim.proxy(function(e) {
      var jadgeAllowMove = e.args.allowMove ? "yes": "no";

      $('#' + jadgeAllowMove + "_radio").prop("checked", true);
      this._model.fetchStorageCapacityThreshold({
        success: function(e) {
          var size;

          size = e.args.size / (1024 * 1024 * 1024);
          $("#empty_capacity").val(size);
         },
        error: dixim.proxy(function() {
          this._showErrorDialog("ctt_error_dialog_default");
        }, this),
        complete: dixim.proxy(function() {
          this._loadingIcon.detach();
          this._didEventForCheckThreshold();
       }, this)});
    }, this),
    error: dixim.proxy(function() {
      this._showErrorDialog("ctt_error_dialog_default");
    }, this)
  });
};

prototype._didRenderDialog = function(e) {
  this._didCreateDialog();
  $('.ui-dialog-buttonset').append(this._loadingIcon);
  this._didSetValueDialog();

  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didTitlebarCloseButtonClick = function(e) {
  e.preventDefault();
  this._didCancel();
};

prototype._didClickCancel = function() {
  this._didCancel();
};

prototype._didCancel = function() {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._didClickSave = function() {
  this.dispatchEvent(new Event(SAVE));
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.addEventListener('close', this._didCloseModalDialog, this);

  dialog.show();
  this._modal = dialog;
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

}());
