/**
 * @module ctt
 * @submodule search-box-view
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var configs = dixim.ctt.Configs.get;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var SearchBoxView;
var prototype;

/**
 * @class SearchBoxView
 * @extends EventTarget
 * @uses Event
 * @uses Configs
 * @uses ResourceBundle
 * @uses jQuery
 * @constructor
 * @param {Object} configs
 */
SearchBoxView = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(SearchBoxView, EventTarget);
dixim.ctt.SearchBoxView = SearchBoxView;
prototype = SearchBoxView.prototype;

var TEMPLATE_SEARCH_BOX_CONTAINER = '<div class="ctt-search-box"></div>';
var TEMPLATE_SEARCH_BOX_FORM = (function() {
  return [
    '<form class="ctt-search-box-form" name="searchform" method="get" action="#">',
    '<input class="ctt-search-box-keywords" name="keywords" value="" type="text" />',
    '<input class="ctt-search-box-search-button" type="image" ',
    ' src="' + configs('imagePath') + '/button_search.jpg"',
    ' alt="'+ _('ctt_search_box_view_search_button_alt_label') + '" ',
    ' name="searchButton" /></form>'
  ].join('');
}());

/**
 * Triggered when the keyword has been submitted.
 * 
 * @event search
 */
var SEARCH = 'search';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {String} configs.containerNode
 */
prototype._initialize = function(configs) {
  this._containerNode = configs.containerNode;
};

/**
 * @method _createView
 * @private
 */
prototype._createView = function() {
  v = $(TEMPLATE_SEARCH_BOX_CONTAINER).appendTo(this._containerNode);
  v.append($(TEMPLATE_SEARCH_BOX_FORM));
  v.bind('submit', $.proxy(this._didSubmitKeyword, this));
  this._view = v;
};

prototype._didSubmitKeyword = function(e) {
  var target = $(e.target);
  var val;

  e.preventDefault();
  val = $('input[name=keywords]', target).val();
  this.dispatchEvent(new Event(SEARCH, {keyword: val}));
};

/**
 * @method show
 */
prototype.show = function() {
  if (!!!this._view) {
    this._createView();
  }
  this._view.show();
};

/**
 * @method hide
 */
prototype.hide = function() {
  this._view.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.hide();
  this._view = null;
};

}());
