/**
 * @module ctt
 * @submodule destination-storage-listing-wizard-page-view
 */
(function() {
var Event = dixim.event.Event;
var WizardPageView = dixim.ctt.WizardPageView;
var TickerView = dixim.ctt.TickerView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var DestinationStorageListingWizardPageView;
var prototype;
var superConstructor;

/**
 * @class DestinationStorageListingWizardPageView
 * @extends WizardPageView
 * @constructor
 * @param {Object} configs
 */
DestinationStorageListingWizardPageView = function(configs) {
  WizardPageView.call(this, configs);
};
dixim.inherit(DestinationStorageListingWizardPageView, WizardPageView);
dixim.ctt.DestinationStorageListingWizardPageView = DestinationStorageListingWizardPageView;
prototype = DestinationStorageListingWizardPageView.prototype;
superConstructor = DestinationStorageListingWizardPageView.superConstructor;

/**
 * Triggered when the view has been rendered.
 * 
 * @event render
 */
var RENDER = 'render';

/**
 * @event back
 */
var BACK = 'back';

/**
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * @event next
 */
var NEXT = 'next';

var TEMPLATE_PAGE_BODY = ['<div class="ctt-destination-storage-listing-wizard-page-view">',
                          '<div class="ctt-destination-storage-listing-wizard-page-view-description">${description}</div>',
                          '<div class="ctt-destination-storage-listing-wizard-page-view-storage-list"></div>',
                          '</div>'].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var cfg;
  var body;

  body = TEMPLATE_PAGE_BODY.
           replace('${description}',
                   _('ctt_destination_storage_listing_wizard_page_view_description'));
  cfg = {
    title: _('ctt_transfer_wizard_title'),
    bodyContent: body
  };

  buttons = [
    {
      text: _('ctt_transfer_wizard_button_label_next'),
      click: $.proxy(this._didClickNext, this),
      'class': 'ctt-destination-storage-listing-wizard-page-view-button-next'
    },
    {
      text: _('ctt_transfer_wizard_button_label_back'),
      click: $.proxy(this._didClickBack, this)
    },
    {
      text: _('ctt_transfer_wizard_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  cfg = dixim.extend(cfg, configs);
  cfg.buttons = buttons;
  superConstructor.prototype._initialize.call(this, cfg);

  this._ticker = null;
};

prototype._didRenderDialog = function(e) {
  var v = this._view;

  this._ticker = new TickerView({
    containerNode: $('.ctt-destination-storage-listing-wizard-page-view-description', v),
    type: 'error'
  });
  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didOpenDialog = function(e) {
  var v = this._view;
  var list;
  var desc;

  superConstructor.prototype._didOpenDialog.call(this, e);

  list = $('.ctt-destination-storage-listing-wizard-page-view-storage-list', v);
  desc = $('.ctt-destination-storage-listing-wizard-page-view-description', v);
  list.height(Math.floor(v.height() - desc.outerHeight()));
};

prototype._didClickNext = function(e) {
  this.dispatchEvent(new Event(NEXT));
};

prototype._didClickCancel = function(e) {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._didClickBack = function(e) {
  this.dispatchEvent(new Event(BACK));
};

prototype.getBodyContent = function() {
  return $('.ctt-destination-storage-listing-wizard-page-view-storage-list',
           this._view);
};

prototype.disableNextButton = function() {
  this.disableButton('.ctt-destination-storage-listing-wizard-page-view-button-next');
};

prototype.enableNextButton = function() {
  this.enableButton('.ctt-destination-storage-listing-wizard-page-view-button-next');
};

prototype.showError = function(error) {
  this._ticker.setText(error);
  this._ticker.show();
};

}());
